@@ -12,14 +12,14 @@ from requests import get, post, put, delete
 if __name__ == "__main__":
     from utils import gitee
     from utils.backend import SqleeColumn, SqleeTable
-    from utils.exceptions import RepositoryNotFoundError, TableNotFoundError
+    from utils.exceptions import RepositoryNotFoundError, TableNotFoundError, RepositoryNotFound
     from utils.urlparse import URL
     from utils.crypto import CryptoHandler
     from config import __version__
 else:
     from .utils import gitee
     from .utils.backend import SqleeColumn, SqleeTable
-    from .utils.exceptions import RepositoryNotFoundError, TableNotFoundError
+    from .utils.exceptions import RepositoryNotFoundError, TableNotFoundError, RepositoryNotFound
     from .utils.urlparse import URL
     from .utils.crypto import CryptoHandler
     from .config import __version__
@@ -36,9 +36,9 @@ class objects:
     def all(self):
         return self.obj.all_tables()
     
-    def get(self, name=None):
+    def get(self, name=None, directly_load=True):
         if name in self.obj.repo.list_folder(path=""):
-            return SqleeTable(name=name, repo=self.obj.repo)
+            return SqleeTable(name=name, repo=self.obj.repo, directly_load=directly_load)
         raise TableNotFoundError(name)
 
     def create(self, name=None, namespace=None):
@@ -61,6 +61,7 @@ class SqleeRepository:
     def __init__(self, access_token, repo, owner, auto_make=False):
         self.access_token = access_token
         if auto_make:
+            print(RepositoryNotFound(repo))
             gitee.make_repo(name=repo, user=owner, token=access_token)
         self.repo = gitee.GiteeRepo(token=access_token, user=owner, repo=repo)
         self.owner = owner
