@@ -9,6 +9,11 @@ import requests
 import json
 import base64
 
+if __name__ == "__main__":
+    from utils.exceptions import RepositoryNotFoundError, RepositoryConnectionRefusedError, InternetError
+else:
+    from .exceptions import RepositoryNotFoundError, RepositoryConnectionRefusedError, InternetError, ColumnNotFoundError
+
 class GiteeRepo:
     token = None
     user = None
@@ -18,17 +23,35 @@ class GiteeRepo:
         self.user = user
         self.repo = repo
         self.url = "https://gitee.com/" + user + "/" + repo + "/"
-        if requests.get(url=self.url).status_code == 404:
-            raise NameError("仓库 %s 不存在." % (self.repo))
+
+        try:
+            query = requests.get(
+                url = "https://gitee.com/api/v5/user/repos",
+                data = {"access_token": token}
+                )
+            all_repos = query.json()
+            exists = False
+            for repos in all_repos:
+                if repo == repos["name"] and user == repos["owner"]["login"]:
+                    exists = True
+            if not exists:
+                raise RepositoryNotFoundError(self.repo)
+            if query.status_code // 100 != 2:
+                raise RepositoryConnectionRefusedError(self.repo, status_code=status_code)
+        except requests.RequestException:
+            raise InternetError()
 
         self.types = {}
         self.types["int"] = int
         self.types["str"] = str
 
     def get_file(self, path=None):
-        return base64.b64decode(json.loads(requests.get(
+        query = requests.get(
             url = f"https://gitee.com/api/v5/repos/{self.user}/{self.repo}/contents/{path}?access_token={self.token}"
-            ).text)["content"].encode()).decode()
+            ).text
+        if query == "[]":
+            raise ColumnNotFoundError(path)
+        return base64.b64decode(json.loads(query)["content"].encode()).decode()
 
     def get_data(self, path=None):
         return json.loads(base64.b64decode(json.loads(requests.get(
@@ -54,10 +77,11 @@ class GiteeRepo:
                 
             if not int:
                 if not dir:
-                    if file["type"] != "dir":
+                    if file["type"] != "dir" and file["name"] != ".keep" and file["name"] != ".namespace":
                         result.append(file["name"])
                 else:
-                    result.append(file["name"])
+                    if file["name"] != ".keep" and file["name"] != ".namespace":
+                        result.append(file["name"])
             else:
                 if file["name"] != ".keep" and file["name"] != ".namespace":
                     if not dir:
@@ -191,7 +215,8 @@ def make_repo(token=None, user=None, name=None, private=True, auto_init=True):
         }
     )
 if __name__ == "__main__":
-    db = GiteeRepo(token="1895956f770eb0e4d08013ee4b753203", user="fu050409", repo="TEST_API")
+    pass
+    #db = GiteeRepo(token="1895956f770eb0e4d08013ee4b753203", user="fu050409", repo="TEST_API")
     #db.drop_folder(path="Table")
     #print(gitee.get_file("TEST"))
     #print(gitee.list_file(""))
